#include "qtOnePanel.h"
#include "ui_qtOnePanel.h"

#include "P3d-pkg.h"
#include "Util-pkg.h"
#include "Planner-pkg.h"
#include "Graphic-pkg.h"
#include "LightPlanner-pkg.h"

#include "planner/planner.hpp"
#include "planner/Diffusion/Variants/Star-RRT.hpp"
#include "planner/TrajectoryOptim/Classic/smoothing.hpp"
#include "planner/TrajectoryOptim/Classic/costOptimization.hpp"
#include "planner/TrajectoryOptim/trajectoryOptim.hpp"
#include "planner/planEnvironment.hpp"
#include "planner/plannerFunctions.hpp"
#include "planner_handler.hpp"

#include "API/project.hpp"

#ifdef HRI_PLANNER
#include <libmove3d/hri/hri.h>
#endif

#include "localpath/proto/p3d_multiLocalPath_proto.h"
#include "qtMainInterface/mainwindow.hpp"
#include "graphic/proto/glwidget.hpp"

using namespace std;

qtOnePanel::qtOnePanel(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::qtOnePanel)
{
    ui->setupUi(this);

    ui->label_LeftFrom->setVisible(false);
    ui->label_LeftFromRotation->setVisible(false);
    ui->label_LeftFromShoulder->setVisible(false);
    ui->label_LeftFromTranslation->setVisible(false);
    ui->label_LeftFromX->setVisible(false);
    ui->label_LeftFromY->setVisible(false);
    ui->label_LeftFromZ->setVisible(false);

    ui->doubleSpinBoxLeftFromShoulder->setVisible(false);
    ui->doubleSpinBoxLeftRotationFromX->setVisible(false);
    ui->doubleSpinBoxLeftRotationFromY->setVisible(false);
    ui->doubleSpinBoxLeftRotationFromZ->setVisible(false);
    ui->doubleSpinBoxLeftTranslationFromX->setVisible(false);
    ui->doubleSpinBoxLeftTranslationFromY->setVisible(false);
    ui->doubleSpinBoxLeftTranslationFromZ->setVisible(false);

    ui->label_LeftTo->setVisible(false);
    ui->label_LeftToRotation->setVisible(false);
    ui->label_LeftToShoulder->setVisible(false);
    ui->label_LeftToTranslation->setVisible(false);
    ui->label_LeftToX->setVisible(false);
    ui->label_LeftToY->setVisible(false);
    ui->label_LeftToZ->setVisible(false);

    ui->doubleSpinBoxLeftToShoulder->setVisible(false);
    ui->doubleSpinBoxLeftRotationToX->setVisible(false);
    ui->doubleSpinBoxLeftRotationToY->setVisible(false);
    ui->doubleSpinBoxLeftRotationToZ->setVisible(false);
    ui->doubleSpinBoxLeftTranslationToX->setVisible(false);
    ui->doubleSpinBoxLeftTranslationToY->setVisible(false);
    ui->doubleSpinBoxLeftTranslationToZ->setVisible(false);

    ui->label_RightFrom->setVisible(false);
    ui->label_RightFromRotation->setVisible(false);
    ui->label_RightFromShoulder->setVisible(false);
    ui->label_RightFromTranslation->setVisible(false);
    ui->label_RightFromX->setVisible(false);
    ui->label_RightFromY->setVisible(false);
    ui->label_RightFromZ->setVisible(false);

    ui->doubleSpinBoxRightFromShoulder->setVisible(false);
    ui->doubleSpinBoxRightRotationFromX->setVisible(false);
    ui->doubleSpinBoxRightRotationFromY->setVisible(false);
    ui->doubleSpinBoxRightRotationFromZ->setVisible(false);
    ui->doubleSpinBoxRightTranslationFromX->setVisible(false);
    ui->doubleSpinBoxRightTranslationFromY->setVisible(false);
    ui->doubleSpinBoxRightTranslationFromZ->setVisible(false);

    ui->label_RightTo->setVisible(false);
    ui->label_RightToRotation->setVisible(false);
    ui->label_RightToShoulder->setVisible(false);
    ui->label_RightToTranslation->setVisible(false);
    ui->label_RightToX->setVisible(false);
    ui->label_RightToY->setVisible(false);
    ui->label_RightToZ->setVisible(false);

    ui->doubleSpinBoxRightToShoulder->setVisible(false);
    ui->doubleSpinBoxRightRotationToX->setVisible(false);
    ui->doubleSpinBoxRightRotationToY->setVisible(false);
    ui->doubleSpinBoxRightRotationToZ->setVisible(false);
    ui->doubleSpinBoxRightTranslationToX->setVisible(false);
    ui->doubleSpinBoxRightTranslationToY->setVisible(false);
    ui->doubleSpinBoxRightTranslationToZ->setVisible(false);



    ui->comboBoxRightObjectChoice->addItem( "" );
    ui->comboBoxLeftObjectChoice->addItem( "" );
    for(int i =0;i<XYZ_ENV->nr;i++)
    {
      if( XYZ_ENV->robot[i]->njoints == 1 )
      {
        if(XYZ_ENV->robot[i]->joints[1]->type == P3D_FREEFLYER || XYZ_ENV->robot[i]->joints[1]->type == P3D_QUADROTOR)
        {
          QString FFname(XYZ_ENV->robot[i]->name);
          ui->comboBoxRightObjectChoice->addItem( FFname );
          ui->comboBoxLeftObjectChoice->addItem( FFname );
        }
      }
    }
}

qtOnePanel::~qtOnePanel()
{
    delete ui;
}

void qtOnePanel::on_pushButtonManip_clicked()
{
    if(global_ActiveRobotName != "PR2_ROBOT")
    {
        cout<<"This panel works exclusively with the PR2 for now"<<endl;
        return;
    }

    Robot* rob = global_Project->getActiveScene()->getRobotByNameContaining( global_ActiveRobotName );
    std::tr1::shared_ptr<Configuration> qInit = rob->getInitialPosition();
    std::tr1::shared_ptr<Configuration> qGoal = rob->getGoTo();





    double* diametre;

    p3d_get_BB_rob_max_size( p3d_get_robot_by_name_containing("HACHET_RIGHT"),diametre);

    cout<<"Dia "<<*diametre<<endl;


    int numberOfActiveArms = 0;

    if(ui->groupBoxRight->isChecked())
    {
        ui->label_RightFrom->setVisible(true);
        ui->label_RightFromRotation->setVisible(true);
        ui->label_RightFromShoulder->setVisible(true);
        ui->label_RightFromTranslation->setVisible(true);
        ui->label_RightFromX->setVisible(true);
        ui->label_RightFromY->setVisible(true);
        ui->label_RightFromZ->setVisible(true);

        ui->doubleSpinBoxRightFromShoulder->setVisible(true);
        ui->doubleSpinBoxRightRotationFromX->setVisible(true);
        ui->doubleSpinBoxRightRotationFromY->setVisible(true);
        ui->doubleSpinBoxRightRotationFromZ->setVisible(true);
        ui->doubleSpinBoxRightTranslationFromX->setVisible(true);
        ui->doubleSpinBoxRightTranslationFromY->setVisible(true);
        ui->doubleSpinBoxRightTranslationFromZ->setVisible(true);

        ui->label_RightTo->setVisible(true);
        ui->label_RightToRotation->setVisible(true);
        ui->label_RightToShoulder->setVisible(true);
        ui->label_RightToTranslation->setVisible(true);
        ui->label_RightToX->setVisible(true);
        ui->label_RightToY->setVisible(true);
        ui->label_RightToZ->setVisible(true);

        ui->doubleSpinBoxRightToShoulder->setVisible(true);
        ui->doubleSpinBoxRightRotationToX->setVisible(true);
        ui->doubleSpinBoxRightRotationToY->setVisible(true);
        ui->doubleSpinBoxRightRotationToZ->setVisible(true);
        ui->doubleSpinBoxRightTranslationToX->setVisible(true);
        ui->doubleSpinBoxRightTranslationToY->setVisible(true);
        ui->doubleSpinBoxRightTranslationToZ->setVisible(true);

        numberOfActiveArms++;
    }

    if(ui->groupBoxLeft->isChecked())
    {
        ui->label_LeftFrom->setVisible(true);
        ui->label_LeftFromRotation->setVisible(true);
        ui->label_LeftFromShoulder->setVisible(true);
        ui->label_LeftFromTranslation->setVisible(true);
        ui->label_LeftFromX->setVisible(true);
        ui->label_LeftFromY->setVisible(true);
        ui->label_LeftFromZ->setVisible(true);

        ui->doubleSpinBoxLeftFromShoulder->setVisible(true);
        ui->doubleSpinBoxLeftRotationFromX->setVisible(true);
        ui->doubleSpinBoxLeftRotationFromY->setVisible(true);
        ui->doubleSpinBoxLeftRotationFromZ->setVisible(true);
        ui->doubleSpinBoxLeftTranslationFromX->setVisible(true);
        ui->doubleSpinBoxLeftTranslationFromY->setVisible(true);
        ui->doubleSpinBoxLeftTranslationFromZ->setVisible(true);

        ui->label_LeftTo->setVisible(true);
        ui->label_LeftToRotation->setVisible(true);
        ui->label_LeftToShoulder->setVisible(true);
        ui->label_LeftToTranslation->setVisible(true);
        ui->label_LeftToX->setVisible(true);
        ui->label_LeftToY->setVisible(true);
        ui->label_LeftToZ->setVisible(true);

        ui->doubleSpinBoxLeftToShoulder->setVisible(true);
        ui->doubleSpinBoxLeftRotationToX->setVisible(true);
        ui->doubleSpinBoxLeftRotationToY->setVisible(true);
        ui->doubleSpinBoxLeftRotationToZ->setVisible(true);
        ui->doubleSpinBoxLeftTranslationToX->setVisible(true);
        ui->doubleSpinBoxLeftTranslationToY->setVisible(true);
        ui->doubleSpinBoxLeftTranslationToZ->setVisible(true);

        numberOfActiveArms++;
    }


    //Fix Joints for Manipulation Cost/Replanning
    if(numberOfActiveArms == 0)
    {
        cout<<"No arm has been activated."<<endl;
        return;
    }
    else if(numberOfActiveArms == 1)
    {
        ENV.setInt(Env::setOfActiveJoints,1);
    }
    else if(numberOfActiveArms == 2)
    {
        ENV.setInt(Env::setOfActiveJoints,3);        //DUAL ARM Manipulation
    }


    //Move cameras
    p3d_rob* robot = p3d_get_robot_by_name(global_ActiveRobotName.c_str());

    //Constraints for Manipulation

    p3d_cntrt* ct;
    // over all constraints
    for(int i=0; i<robot->cntrt_manager->ncntrts; i++)
    {
        string name = robot->cntrt_manager->cntrts[i]->namecntrt;

        if( name == "p3d_fix_jnts_relpos" ){
            continue;
        }
        // get constraint from the cntrts manager
        ct = robot->cntrt_manager->cntrts[i];
        p3d_desactivateCntrt( robot, ct );
    }

    p3d_multiLocalPath_disable_all_groupToPlan( robot , false );
    p3d_multiLocalPath_set_groupToPlan( robot, 2, 1, false);


    //Fix every joint except the active arm(s)
    for (int i = 0; i < robot->njoints + 1; i++) {
        p3d_jnt * joint = robot->joints[i];
        if (joint->type != P3D_BASE && joint->type != P3D_FIXED) {
            fixJoint(robot, joint, joint->jnt_mat);
        }
    }

    if(ui->groupBoxRight->isChecked())
    {

        ArmManipulationData& mData = (*robot->armManipulationData)[0];
        ct = mData.getCcCntrt();
        for(int i = 0; i < ct->npasjnts; i++){
            p3d_jnt * joint = ct->pasjnts[i];
            if(joint->type != P3D_FIXED){
                unFixJoint(robot, joint);
            }
        }
        if((!strcmp(ct->namecntrt, "p3d_kuka_arm_ik")) ||
                (!strcmp(ct->namecntrt, "p3d_lwr_arm_ik")) ||
                (!strcmp(ct->namecntrt, "p3d_pr2_arm_ik"))){
            p3d_jnt * joint = robot->joints[ct->argu_i[0]];
            unFixJoint(robot, joint);
        }

        mData.setCartesian( true );
    }
    else
    {
        ArmManipulationData& mData = (*robot->armManipulationData)[0];
        mData.setCartesian( false );

    }

    if(ui->groupBoxLeft->isChecked())
    {

        ArmManipulationData& mData = (*robot->armManipulationData)[1];
        ct = mData.getCcCntrt();
        for(int i = 0; i < ct->npasjnts; i++){
            p3d_jnt * joint = ct->pasjnts[i];
            if(joint->type != P3D_FIXED){
                unFixJoint(robot, joint);
            }
        }
        if((!strcmp(ct->namecntrt, "p3d_kuka_arm_ik")) ||
                (!strcmp(ct->namecntrt, "p3d_lwr_arm_ik")) ||
                (!strcmp(ct->namecntrt, "p3d_pr2_arm_ik"))){
            p3d_jnt * joint = robot->joints[ct->argu_i[0]];
            unFixJoint(robot, joint);
        }
        mData.setCartesian( true );
    }

    else
    {
        ArmManipulationData& mData = (*robot->armManipulationData)[1];
        mData.setCartesian( false );

    }

    p3d_update_this_robot_pos(robot);


    ManipulationPlanner* test = new ManipulationPlanner(robot);                                 //CHERCHER ce qui est global

    //Connect Object to gripper

    if(ui->groupBoxRight->isChecked() && ui->comboBoxRightObjectChoice->currentText() != NULL)
    {
        QString str1R = ui->comboBoxRightObjectChoice->currentText();
        QByteArray baR = str1R.toLocal8Bit();
        const char *nameR = baR.data();
        hri_agent_is_grasping_obj_rob_pt(robot, true , nameR , 0);

        Robot* object = global_Project->getActiveScene()->getRobotByNameContaining( nameR );
        std::tr1::shared_ptr<Configuration> qInitO = object->getInitialPosition();
        std::tr1::shared_ptr<Configuration> qGoalO = object->getGoTo();

        qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[0].v = (*qInitO)[0];
        qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[1].v = (*qInitO)[1];
        qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[2].v = (*qInitO)[2];

        qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[3].v = (*qInitO)[3];
        qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[4].v = (*qInitO)[4];
        qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[5].v = (*qInitO)[5];

        qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[0].v = (*qGoalO)[0];
        qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[1].v = (*qGoalO)[1];
        qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[2].v = (*qGoalO)[2];

        qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[3].v = (*qGoalO)[3];
        qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[4].v = (*qGoalO)[4];
        qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[5].v = (*qGoalO)[5];


    }

    if(ui->groupBoxLeft->isChecked() && ui->comboBoxLeftObjectChoice->currentText() != NULL)
    {
        QString str1L = ui->comboBoxLeftObjectChoice->currentText();
        QByteArray baL = str1L.toLocal8Bit();
        const char *nameL = baL.data();
        hri_agent_is_grasping_obj_rob_pt(robot, true , nameL , 1);

        Robot* object = global_Project->getActiveScene()->getRobotByNameContaining( nameL );
        std::tr1::shared_ptr<Configuration> qInitO = object->getInitialPosition();
        std::tr1::shared_ptr<Configuration> qGoalO = object->getGoTo();

        qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[0].v = (*qInitO)[0];
        qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[1].v = (*qInitO)[1];
        qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[2].v = (*qInitO)[2];

        qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[3].v = (*qInitO)[3];
        qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[4].v = (*qInitO)[4];
        qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[5].v = (*qInitO)[5];

        qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[0].v = (*qGoalO)[0];
        qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[1].v = (*qGoalO)[1];
        qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[2].v = (*qGoalO)[2];

        qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[3].v = (*qGoalO)[3];
        qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[4].v = (*qGoalO)[4];
        qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[5].v = (*qGoalO)[5];
    }

    //Set the cartesian mode for the active arm(s)
    rob->setAndUpdate(*qInit);
    configPt q = qInit->getConfigStruct();

    for (int i=0; i < int((*robot->armManipulationData).size()); i++)
    {
        ArmManipulationData& armData  = (*robot->armManipulationData)[i];

        desactivateTwoJointsFixCntrt(robot,armData.getManipulationJnt(), armData.getCcCntrt()->pasjnts[ armData.getCcCntrt()->npasjnts-1 ]);


        if (armData.getCartesian())
        {
            cout << "Arm Data " << i <<  " is set cartesian" << endl;
            activateCcCntrts(robot, i, false);
            ManipulationUtils::unfixManipulationJoints(robot, i);
            shootTheObjectArroundTheBase(robot, robot->baseJnt, armData.getManipulationJnt(), 2.0);
            armData.getManipulationJnt()->dist  = 0.10;

        } else {
            deactivateCcCntrts(robot, i);
            p3d_set_and_update_this_robot_conf(robot, q);
            setAndActivateTwoJointsFixCntrt(robot,armData.getManipulationJnt(), armData.getCcCntrt()->pasjnts[ armData.getCcCntrt()->npasjnts-1 ]);
            ManipulationUtils::fixManipulationJoints(robot, i, q, NULL);
            shootTheObjectInTheWorld(robot, armData.getManipulationJnt());
        }
    }
    p3d_set_and_update_this_robot_conf(robot, q);
    p3d_get_robot_config_into(robot, &q);

    ENV.setBool(Env::isInverseKinematics,true);



    //Init spinbox
    ui->doubleSpinBoxRightTranslationFromX->setValue(  qInit->getRobot()->getJoint("virtual_object_right")->getJointDof(0));
    ui->doubleSpinBoxRightTranslationFromX->setMaximum(qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[0].vmax);
    ui->doubleSpinBoxRightTranslationFromX->setMinimum(qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[0].vmin);
    ui->doubleSpinBoxRightTranslationFromX->setSingleStep((ui->doubleSpinBoxRightTranslationFromX->maximum() - ui->doubleSpinBoxRightTranslationFromX->minimum())/200);
    ui->doubleSpinBoxRightTranslationFromY->setValue(  qInit->getRobot()->getJoint("virtual_object_right")->getJointDof(1));
    ui->doubleSpinBoxRightTranslationFromY->setMaximum(qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[1].vmax);
    ui->doubleSpinBoxRightTranslationFromY->setMinimum(qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[1].vmin);
    ui->doubleSpinBoxRightTranslationFromY->setSingleStep((ui->doubleSpinBoxRightTranslationFromY->maximum() - ui->doubleSpinBoxRightTranslationFromY->minimum())/200);
    ui->doubleSpinBoxRightTranslationFromZ->setValue(  qInit->getRobot()->getJoint("virtual_object_right")->getJointDof(2));
    ui->doubleSpinBoxRightTranslationFromZ->setMaximum(qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[2].vmax);
    ui->doubleSpinBoxRightTranslationFromZ->setMinimum(qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[2].vmin);
    ui->doubleSpinBoxRightTranslationFromZ->setSingleStep((ui->doubleSpinBoxRightTranslationFromZ->maximum() - ui->doubleSpinBoxRightTranslationFromZ->minimum())/200);

    ui->doubleSpinBoxRightRotationFromX->setValue(  qInit->getRobot()->getJoint("virtual_object_right")->getJointDof(3)*180/M_PI);
    ui->doubleSpinBoxRightRotationFromX->setMaximum(qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[3].vmax*180/M_PI);
    ui->doubleSpinBoxRightRotationFromX->setMinimum(qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[3].vmin*180/M_PI);
    ui->doubleSpinBoxRightRotationFromX->setSingleStep((ui->doubleSpinBoxRightRotationFromX->maximum() - ui->doubleSpinBoxRightRotationFromX->minimum())/200);
    ui->doubleSpinBoxRightRotationFromY->setValue(  qInit->getRobot()->getJoint("virtual_object_right")->getJointDof(4)*180/M_PI);
    ui->doubleSpinBoxRightRotationFromY->setMaximum(qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[4].vmax*180/M_PI);
    ui->doubleSpinBoxRightRotationFromY->setMinimum(qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[4].vmin*180/M_PI);
    ui->doubleSpinBoxRightRotationFromY->setSingleStep((ui->doubleSpinBoxRightRotationFromY->maximum() - ui->doubleSpinBoxRightRotationFromY->minimum())/200);
    ui->doubleSpinBoxRightRotationFromZ->setValue(  qInit->getRobot()->getJoint("virtual_object_right")->getJointDof(5)*180/M_PI);
    ui->doubleSpinBoxRightRotationFromZ->setMaximum(qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[5].vmax*180/M_PI);
    ui->doubleSpinBoxRightRotationFromZ->setMinimum(qInit->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[5].vmin*180/M_PI);
    ui->doubleSpinBoxRightRotationFromZ->setSingleStep((ui->doubleSpinBoxRightRotationFromZ->maximum() - ui->doubleSpinBoxRightRotationFromZ->minimum())/200);

    ui->doubleSpinBoxRightFromShoulder->setValue(  qInit->getRobot()->getJoint("right-Arm3")->getJointDof(0)*180/M_PI);
    ui->doubleSpinBoxRightFromShoulder->setMaximum(qInit->getRobot()->getJoint("right-Arm3")->getJointStruct()->dof_data[0].vmax*180/M_PI);
    ui->doubleSpinBoxRightFromShoulder->setMinimum(qInit->getRobot()->getJoint("right-Arm3")->getJointStruct()->dof_data[0].vmin*180/M_PI);
    ui->doubleSpinBoxRightFromShoulder->setSingleStep((ui->doubleSpinBoxRightFromShoulder->maximum() - ui->doubleSpinBoxRightFromShoulder->minimum())/200);

    ui->doubleSpinBoxLeftTranslationFromX->setValue(  qInit->getRobot()->getJoint("virtual_object_left")->getJointDof(0));
    ui->doubleSpinBoxLeftTranslationFromX->setMaximum(qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[0].vmax);
    ui->doubleSpinBoxLeftTranslationFromX->setMinimum(qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[0].vmin);
    ui->doubleSpinBoxLeftTranslationFromX->setSingleStep((ui->doubleSpinBoxLeftTranslationFromX->maximum() - ui->doubleSpinBoxLeftTranslationFromX->minimum())/200);
    ui->doubleSpinBoxLeftTranslationFromY->setValue(  qInit->getRobot()->getJoint("virtual_object_left")->getJointDof(1));
    ui->doubleSpinBoxLeftTranslationFromY->setMaximum(qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[1].vmax);
    ui->doubleSpinBoxLeftTranslationFromY->setMinimum(qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[1].vmin);
    ui->doubleSpinBoxLeftTranslationFromY->setSingleStep((ui->doubleSpinBoxLeftTranslationFromY->maximum() - ui->doubleSpinBoxLeftTranslationFromY->minimum())/200);
    ui->doubleSpinBoxLeftTranslationFromZ->setValue(  qInit->getRobot()->getJoint("virtual_object_left")->getJointDof(2));
    ui->doubleSpinBoxLeftTranslationFromZ->setMaximum(qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[2].vmax);
    ui->doubleSpinBoxLeftTranslationFromZ->setMinimum(qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[2].vmin);
    ui->doubleSpinBoxLeftTranslationFromZ->setSingleStep((ui->doubleSpinBoxLeftTranslationFromZ->maximum() - ui->doubleSpinBoxLeftTranslationFromZ->minimum())/200);

    ui->doubleSpinBoxLeftRotationFromX->setValue(  qInit->getRobot()->getJoint("virtual_object_left")->getJointDof(3)*180/M_PI);
    ui->doubleSpinBoxLeftRotationFromX->setMaximum(qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[3].vmax*180/M_PI);
    ui->doubleSpinBoxLeftRotationFromX->setMinimum(qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[3].vmin*180/M_PI);
    ui->doubleSpinBoxLeftRotationFromX->setSingleStep((ui->doubleSpinBoxLeftRotationFromX->maximum() - ui->doubleSpinBoxLeftRotationFromX->minimum())/200);
    ui->doubleSpinBoxLeftRotationFromY->setValue(  qInit->getRobot()->getJoint("virtual_object_left")->getJointDof(4)*180/M_PI);
    ui->doubleSpinBoxLeftRotationFromY->setMaximum(qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[4].vmax*180/M_PI);
    ui->doubleSpinBoxLeftRotationFromY->setMinimum(qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[4].vmin*180/M_PI);
    ui->doubleSpinBoxLeftRotationFromY->setSingleStep((ui->doubleSpinBoxLeftRotationFromY->maximum() - ui->doubleSpinBoxLeftRotationFromY->minimum())/200);
    ui->doubleSpinBoxLeftRotationFromZ->setValue(  qInit->getRobot()->getJoint("virtual_object_left")->getJointDof(5)*180/M_PI);
    ui->doubleSpinBoxLeftRotationFromZ->setMaximum(qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[5].vmax*180/M_PI);
    ui->doubleSpinBoxLeftRotationFromZ->setMinimum(qInit->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[5].vmin*180/M_PI);
    ui->doubleSpinBoxLeftRotationFromZ->setSingleStep((ui->doubleSpinBoxLeftRotationFromZ->maximum() - ui->doubleSpinBoxLeftRotationFromZ->minimum())/200);

    ui->doubleSpinBoxLeftFromShoulder->setValue(  qInit->getRobot()->getJoint("left-Arm3")->getJointDof(0)*180/M_PI);
    ui->doubleSpinBoxLeftFromShoulder->setMaximum(qInit->getRobot()->getJoint("left-Arm3")->getJointStruct()->dof_data[0].vmax*180/M_PI);
    ui->doubleSpinBoxLeftFromShoulder->setMinimum(qInit->getRobot()->getJoint("left-Arm3")->getJointStruct()->dof_data[0].vmin*180/M_PI);
    ui->doubleSpinBoxLeftFromShoulder->setSingleStep((ui->doubleSpinBoxLeftFromShoulder->maximum() - ui->doubleSpinBoxLeftFromShoulder->minimum())/200);


    rob->setAndUpdate(*qGoal);

    ui->doubleSpinBoxRightTranslationToX->setValue(  qGoal->getRobot()->getJoint("virtual_object_right")->getJointDof(0));
    ui->doubleSpinBoxRightTranslationToX->setMaximum(qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[0].vmax);
    ui->doubleSpinBoxRightTranslationToX->setMinimum(qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[0].vmin);
    ui->doubleSpinBoxRightTranslationToX->setSingleStep((ui->doubleSpinBoxRightTranslationToX->maximum() - ui->doubleSpinBoxRightTranslationToX->minimum())/200);
    ui->doubleSpinBoxRightTranslationToY->setValue(  qGoal->getRobot()->getJoint("virtual_object_right")->getJointDof(1));
    ui->doubleSpinBoxRightTranslationToY->setMaximum(qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[1].vmax);
    ui->doubleSpinBoxRightTranslationToY->setMinimum(qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[1].vmin);
    ui->doubleSpinBoxRightTranslationToY->setSingleStep((ui->doubleSpinBoxRightTranslationToY->maximum() - ui->doubleSpinBoxRightTranslationToY->minimum())/200);
    ui->doubleSpinBoxRightTranslationToZ->setValue(  qGoal->getRobot()->getJoint("virtual_object_right")->getJointDof(2));
    ui->doubleSpinBoxRightTranslationToZ->setMaximum(qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[2].vmax);
    ui->doubleSpinBoxRightTranslationToZ->setMinimum(qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[2].vmin);
    ui->doubleSpinBoxRightTranslationToZ->setSingleStep((ui->doubleSpinBoxRightTranslationToZ->maximum() - ui->doubleSpinBoxRightTranslationToZ->minimum())/200);

    ui->doubleSpinBoxRightRotationToX->setValue(  qGoal->getRobot()->getJoint("virtual_object_right")->getJointDof(3)*180/M_PI);
    ui->doubleSpinBoxRightRotationToX->setMaximum(qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[3].vmax*180/M_PI);
    ui->doubleSpinBoxRightRotationToX->setMinimum(qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[3].vmin*180/M_PI);
    ui->doubleSpinBoxRightRotationToX->setSingleStep((ui->doubleSpinBoxRightRotationToX->maximum() - ui->doubleSpinBoxRightRotationToX->minimum())/200);
    ui->doubleSpinBoxRightRotationToY->setValue(  qGoal->getRobot()->getJoint("virtual_object_right")->getJointDof(4)*180/M_PI);
    ui->doubleSpinBoxRightRotationToY->setMaximum(qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[4].vmax*180/M_PI);
    ui->doubleSpinBoxRightRotationToY->setMinimum(qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[4].vmin*180/M_PI);
    ui->doubleSpinBoxRightRotationToY->setSingleStep((ui->doubleSpinBoxRightRotationToY->maximum() - ui->doubleSpinBoxRightRotationToY->minimum())/200);
    ui->doubleSpinBoxRightRotationToZ->setValue(  qGoal->getRobot()->getJoint("virtual_object_right")->getJointDof(5)*180/M_PI);
    ui->doubleSpinBoxRightRotationToZ->setMaximum(qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[5].vmax*180/M_PI);
    ui->doubleSpinBoxRightRotationToZ->setMinimum(qGoal->getRobot()->getJoint("virtual_object_right")->getJointStruct()->dof_data[5].vmin*180/M_PI);
    ui->doubleSpinBoxRightRotationToZ->setSingleStep((ui->doubleSpinBoxRightRotationToZ->maximum() - ui->doubleSpinBoxRightRotationToZ->minimum())/200);

    ui->doubleSpinBoxRightToShoulder->setValue(  qGoal->getRobot()->getJoint("right-Arm3")->getJointDof(0)*180/M_PI);
    ui->doubleSpinBoxRightToShoulder->setMaximum(qGoal->getRobot()->getJoint("right-Arm3")->getJointStruct()->dof_data[0].vmax*180/M_PI);
    ui->doubleSpinBoxRightToShoulder->setMinimum(qGoal->getRobot()->getJoint("right-Arm3")->getJointStruct()->dof_data[0].vmin*180/M_PI);
    ui->doubleSpinBoxRightToShoulder->setSingleStep((ui->doubleSpinBoxRightToShoulder->maximum() - ui->doubleSpinBoxRightToShoulder->minimum())/200);

    ui->doubleSpinBoxLeftTranslationToX->setValue(  qGoal->getRobot()->getJoint("virtual_object_left")->getJointDof(0));
    ui->doubleSpinBoxLeftTranslationToX->setMaximum(qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[0].vmax);
    ui->doubleSpinBoxLeftTranslationToX->setMinimum(qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[0].vmin);
    ui->doubleSpinBoxLeftTranslationToX->setSingleStep((ui->doubleSpinBoxLeftTranslationToX->maximum() - ui->doubleSpinBoxLeftTranslationToX->minimum())/200);
    ui->doubleSpinBoxLeftTranslationToY->setValue(  qGoal->getRobot()->getJoint("virtual_object_left")->getJointDof(1));
    ui->doubleSpinBoxLeftTranslationToY->setMaximum(qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[1].vmax);
    ui->doubleSpinBoxLeftTranslationToY->setMinimum(qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[1].vmin);
    ui->doubleSpinBoxLeftTranslationToY->setSingleStep((ui->doubleSpinBoxLeftTranslationToY->maximum() - ui->doubleSpinBoxLeftTranslationToY->minimum())/200);
    ui->doubleSpinBoxLeftTranslationToZ->setValue(  qGoal->getRobot()->getJoint("virtual_object_left")->getJointDof(2));
    ui->doubleSpinBoxLeftTranslationToZ->setMaximum(qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[2].vmax);
    ui->doubleSpinBoxLeftTranslationToZ->setMinimum(qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[2].vmin);
    ui->doubleSpinBoxLeftTranslationToZ->setSingleStep((ui->doubleSpinBoxLeftTranslationToZ->maximum() - ui->doubleSpinBoxLeftTranslationToZ->minimum())/200);

    ui->doubleSpinBoxLeftRotationToX->setValue(  qGoal->getRobot()->getJoint("virtual_object_left")->getJointDof(3)*180/M_PI);
    ui->doubleSpinBoxLeftRotationToX->setMaximum(qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[3].vmax*180/M_PI);
    ui->doubleSpinBoxLeftRotationToX->setMinimum(qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[3].vmin*180/M_PI);
    ui->doubleSpinBoxLeftRotationToX->setSingleStep((ui->doubleSpinBoxLeftRotationToX->maximum() - ui->doubleSpinBoxLeftRotationToX->minimum())/200);
    ui->doubleSpinBoxLeftRotationToY->setValue(  qGoal->getRobot()->getJoint("virtual_object_left")->getJointDof(4)*180/M_PI);
    ui->doubleSpinBoxLeftRotationToY->setMaximum(qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[4].vmax*180/M_PI);
    ui->doubleSpinBoxLeftRotationToY->setMinimum(qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[4].vmin*180/M_PI);
    ui->doubleSpinBoxLeftRotationToY->setSingleStep((ui->doubleSpinBoxLeftRotationToY->maximum() - ui->doubleSpinBoxLeftRotationToY->minimum())/200);
    ui->doubleSpinBoxLeftRotationToZ->setValue(  qGoal->getRobot()->getJoint("virtual_object_left")->getJointDof(5)*180/M_PI);
    ui->doubleSpinBoxLeftRotationToZ->setMaximum(qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[5].vmax*180/M_PI);
    ui->doubleSpinBoxLeftRotationToZ->setMinimum(qGoal->getRobot()->getJoint("virtual_object_left")->getJointStruct()->dof_data[5].vmin*180/M_PI);
    ui->doubleSpinBoxLeftRotationToZ->setSingleStep((ui->doubleSpinBoxLeftRotationToZ->maximum() - ui->doubleSpinBoxLeftRotationToZ->minimum())/200);

    ui->doubleSpinBoxLeftToShoulder->setValue(  qGoal->getRobot()->getJoint("left-Arm3")->getJointDof(0)*180/M_PI);
    ui->doubleSpinBoxLeftToShoulder->setMaximum(qGoal->getRobot()->getJoint("left-Arm3")->getJointStruct()->dof_data[0].vmax*180/M_PI);
    ui->doubleSpinBoxLeftToShoulder->setMinimum(qGoal->getRobot()->getJoint("left-Arm3")->getJointStruct()->dof_data[0].vmin*180/M_PI);
    ui->doubleSpinBoxLeftToShoulder->setSingleStep((ui->doubleSpinBoxLeftToShoulder->maximum() - ui->doubleSpinBoxLeftToShoulder->minimum())/200);


    rob->setAndUpdate(*qInit);


}

void qtOnePanel::on_pushButtonMobileManip_clicked()
{

    //Move cameras
    p3d_rob* robot = p3d_get_robot_by_name(global_ActiveRobotName.c_str());

    //Fix Joints for Manipulation Cost/Replanning
    //Check Manip
    ENV.setInt(Env::setOfActiveJoints,1);
    //Click Fix joints

    p3d_cntrt* ct;

    // over all constraints
    for(int i=0; i<robot->cntrt_manager->ncntrts; i++)
    {
        string name = robot->cntrt_manager->cntrts[i]->namecntrt;

        if( name == "p3d_fix_jnts_relpos" ){
            continue;
        }

        cout << "deactivate : " << robot->name << " , " << name << endl;

        // get constraint from the cntrts manager
        ct = robot->cntrt_manager->cntrts[i];
        p3d_desactivateCntrt( robot, ct );
    }

    p3d_multiLocalPath_disable_all_groupToPlan( robot , false );
    p3d_multiLocalPath_set_groupToPlan( robot, 2, 1, false);

    for (int i = 0; i < robot->njoints + 1; i++) {
        p3d_jnt * joint = robot->joints[i];
        if (joint->type != P3D_BASE && joint->type != P3D_FIXED) {
            fixJoint(robot, joint, joint->jnt_mat);
        }
    }
    ArmManipulationData mData = (*robot->armManipulationData)[0];
    ct = mData.getCcCntrt();
    for(int i = 0; i < ct->npasjnts; i++){
        p3d_jnt * joint = ct->pasjnts[i];
        if(joint->type != P3D_FIXED){
            unFixJoint(robot, joint);
        }
    }
    if((!strcmp(ct->namecntrt, "p3d_kuka_arm_ik")) ||
            (!strcmp(ct->namecntrt, "p3d_lwr_arm_ik")) ||
            (!strcmp(ct->namecntrt, "p3d_pr2_arm_ik"))){
        p3d_jnt * joint = robot->joints[ct->argu_i[0]];
        unFixJoint(robot, joint);
    }

    mData = (*robot->armManipulationData)[1];
    ct = mData.getCcCntrt();
    for(int i = 0; i < ct->npasjnts; i++){
        p3d_jnt * joint = ct->pasjnts[i];
        if(joint->type != P3D_FIXED){
            unFixJoint(robot, joint);
        }
    }
    if((!strcmp(ct->namecntrt, "p3d_kuka_arm_ik")) ||
            (!strcmp(ct->namecntrt, "p3d_lwr_arm_ik")) ||
            (!strcmp(ct->namecntrt, "p3d_pr2_arm_ik"))){
        p3d_jnt * joint = robot->joints[ct->argu_i[0]];
        unFixJoint(robot, joint);
    }

    p3d_update_this_robot_pos(robot);

    //Connect object Robot/Manipulation
    //Click Reset

    ManipulationPlanner* test = new ManipulationPlanner(robot); //CHERCHER ce qui est global

    QString str1R = "HACHET_RIGHT";
    QByteArray baR = str1R.toLocal8Bit();
    const char *nameR = baR.data();
    hri_agent_is_grasping_obj_rob_pt(robot, true , nameR , 0);

    QString str1L = "HACHET_LEFT";
    QByteArray baL = str1L.toLocal8Bit();
    const char *nameL = baL.data();
    hri_agent_is_grasping_obj_rob_pt(robot, true , nameL , 1);

    //Go to cartesian Robot/Model
    //Click 2 times on Switch From FK/IK

    configPt q = p3d_get_robot_config(robot);

    ArmManipulationData& armDataRight  = (*robot->armManipulationData)[0];
    armDataRight.setCartesian( true );
    ArmManipulationData& armDataLeft  = (*robot->armManipulationData)[1];
    armDataLeft.setCartesian( true );

    // For Each Arm
    for (int i=0; i < int((*robot->armManipulationData).size()); i++)
    {
        ArmManipulationData& armData  = (*robot->armManipulationData)[i];

        desactivateTwoJointsFixCntrt(robot,armData.getManipulationJnt(), armData.getCcCntrt()->pasjnts[ armData.getCcCntrt()->npasjnts-1 ]);


        if (armData.getCartesian())
        {
            cout << "Arm Data " << i <<  " is set cartesian" << endl;
            activateCcCntrts(robot, i, false);
            ManipulationUtils::unfixManipulationJoints(robot, i);
            shootTheObjectArroundTheBase(robot, robot->baseJnt, armData.getManipulationJnt(), 2.0);
            armData.getManipulationJnt()->dist  = 0.10;

        } else {
            deactivateCcCntrts(robot, i);
            p3d_set_and_update_this_robot_conf(robot, q);
            setAndActivateTwoJointsFixCntrt(robot,armData.getManipulationJnt(), armData.getCcCntrt()->pasjnts[ armData.getCcCntrt()->npasjnts-1 ]);
            ManipulationUtils::fixManipulationJoints(robot, i, q, NULL);
            shootTheObjectInTheWorld(robot, armData.getManipulationJnt());
        }
    }
    p3d_set_and_update_this_robot_conf(robot, q);
    p3d_get_robot_config_into(robot, &q);
    p3d_destroy_config(robot, q);
    ENV.setBool(Env::isInverseKinematics,true);

}

void qtOnePanel::updateRobotQInitGoal(int dofNum, double value, bool init)
{
    configPt p=NULL, p_deg=NULL;
    int nb_dof,ir,i_dof;
    p3d_rob *robotPt;
    p3d_jnt *jntPt;
    int I_can;
    int nreshoot;
    int *ikSol = NULL;

    double val = value;
    int arg = dofNum;
    Robot* rob = global_Project->getActiveScene()->getRobotByNameContaining( global_ActiveRobotName );

    if(init)
    {
        std::tr1::shared_ptr<Configuration> qInit = rob->getInitialPosition();
        rob->setAndUpdate(*qInit);
    }
    else
    {
        std::tr1::shared_ptr<Configuration> qGoal = rob->getGoTo();
        rob->setAndUpdate(*qGoal);
    }

    nb_dof =    rob->getRobotStruct()->nb_dof;
    ir =        rob->getRobotStruct()->num;
    robotPt =   rob->getRobotStruct();

    p = p3d_alloc_config(robotPt);


    p_deg = p3d_get_robot_config_deg(robotPt);

    p_deg[arg] = val;
    p3d_convert_config_deg_to_rad(robotPt, p_deg, &p);

    p3d_set_robot_config(robotPt, p);
    I_can = p3d_update_this_robot_pos_multisol(robotPt, NULL, 0, ikSol);

    if (robotPt->cntrt_manager->cntrts != NULL)
    {
        nreshoot = 0;
        if(!I_can && p3d_get_RLG())
        {
            if(robotPt->cntrt_manager->in_cntrt[arg] == 1)
            {
                while(!I_can && (nreshoot < 100))
                {
                    if(p3d_random_loop_generator_without_parallel(robotPt, p))
                    {
                        I_can = p3d_update_robot_pos();
                    }
                    nreshoot++;
                }
            }
        }
        if(I_can)
        {
            p3d_get_robot_config_into(robotPt, &p);
            p3d_get_robot_config_deg_into(robotPt, &p_deg);
        }
        else
        {
            p3d_convert_config_deg_to_rad(robotPt, p_deg, &p);
            jntPt = p3d_robot_dof_to_jnt(robotPt, arg, &i_dof);
            p3d_jnt_set_dof_deg(jntPt, i_dof, p_deg[arg]);  /* ceneccasy lines for some cases of cntrts !!! */
            p3d_update_this_robot_pos_without_cntrt(robotPt);
        }
    }

    if(init)
    {
        rob->setInitialPosition(*rob->getCurrentPos());
    }
    else
    {
        rob->setGoTo(*rob->getCurrentPos());
    }

    p3d_destroy_config(robotPt, p);
    p3d_destroy_config(robotPt, p_deg);


    if(!ENV.getBool(Env::isRunning))
    {
        global_w->getOpenGL()->updateGL();
    }
}


void qtOnePanel::on_doubleSpinBoxRightTranslationFromX_valueChanged(double arg1)
{
    updateRobotQInitGoal(37,arg1);
}

void qtOnePanel::on_doubleSpinBoxRightTranslationFromY_valueChanged(double arg1)
{
    updateRobotQInitGoal(38,arg1);
}

void qtOnePanel::on_doubleSpinBoxRightTranslationFromZ_valueChanged(double arg1)
{
    updateRobotQInitGoal(39,arg1);
}

void qtOnePanel::on_doubleSpinBoxRightRotationFromX_valueChanged(double arg1)
{
    updateRobotQInitGoal(40,arg1);
}

void qtOnePanel::on_doubleSpinBoxRightRotationFromY_valueChanged(double arg1)
{
    updateRobotQInitGoal(41,arg1);
}

void qtOnePanel::on_doubleSpinBoxRightRotationFromZ_valueChanged(double arg1)
{
    updateRobotQInitGoal(42,arg1);
}

void qtOnePanel::on_doubleSpinBoxRightFromShoulder_valueChanged(double arg1)
{
    updateRobotQInitGoal(18,arg1);
}

void qtOnePanel::on_doubleSpinBoxRightTranslationToX_valueChanged(double arg1)
{
    updateRobotQInitGoal(37,arg1,false);
}

void qtOnePanel::on_doubleSpinBoxRightTranslationToY_valueChanged(double arg1)
{
    updateRobotQInitGoal(38,arg1,false);
}

void qtOnePanel::on_doubleSpinBoxRightTranslationToZ_valueChanged(double arg1)
{
    updateRobotQInitGoal(39,arg1,false);
}

void qtOnePanel::on_doubleSpinBoxRightRotationToX_valueChanged(double arg1)
{
    updateRobotQInitGoal(40,arg1,false);
}

void qtOnePanel::on_doubleSpinBoxRightRotationToY_valueChanged(double arg1)
{
    updateRobotQInitGoal(41,arg1,false);
}

void qtOnePanel::on_doubleSpinBoxRightRotationToZ_valueChanged(double arg1)
{
    updateRobotQInitGoal(42,arg1,false);
}

void qtOnePanel::on_doubleSpinBoxRightToShoulder_valueChanged(double arg1)
{
    updateRobotQInitGoal(18,arg1,false);
}

void qtOnePanel::on_doubleSpinBoxLeftTranslationFromX_valueChanged(double arg1)
{
    updateRobotQInitGoal(43,arg1);
}

void qtOnePanel::on_doubleSpinBoxLeftTranslationFromY_valueChanged(double arg1)
{
    updateRobotQInitGoal(44,arg1);
}

void qtOnePanel::on_doubleSpinBoxLeftTranslationFromZ_valueChanged(double arg1)
{
    updateRobotQInitGoal(45,arg1);
}

void qtOnePanel::on_doubleSpinBoxLeftRotationFromX_valueChanged(double arg1)
{
    updateRobotQInitGoal(46,arg1);
}

void qtOnePanel::on_doubleSpinBoxLeftRotationFromY_valueChanged(double arg1)
{
    updateRobotQInitGoal(47,arg1);
}

void qtOnePanel::on_doubleSpinBoxLeftRotationFromZ_valueChanged(double arg1)
{
    updateRobotQInitGoal(48,arg1);
}

void qtOnePanel::on_doubleSpinBoxLeftFromShoulder_valueChanged(double arg1)
{
    updateRobotQInitGoal(27,arg1);
}

void qtOnePanel::on_doubleSpinBoxLeftTranslationToX_valueChanged(double arg1)
{
    updateRobotQInitGoal(43,arg1,false);
}

void qtOnePanel::on_doubleSpinBoxLeftTranslationToY_valueChanged(double arg1)
{
    updateRobotQInitGoal(44,arg1,false);
}

void qtOnePanel::on_doubleSpinBoxLeftTranslationToZ_valueChanged(double arg1)
{
    updateRobotQInitGoal(45,arg1,false);
}

void qtOnePanel::on_doubleSpinBoxLeftRotationToX_valueChanged(double arg1)
{
    updateRobotQInitGoal(46,arg1,false);
}

void qtOnePanel::on_doubleSpinBoxLeftRotationToY_valueChanged(double arg1)
{
    updateRobotQInitGoal(47,arg1,false);
}

void qtOnePanel::on_doubleSpinBoxLeftRotationToZ_valueChanged(double arg1)
{
    updateRobotQInitGoal(48,arg1,false);
}

void qtOnePanel::on_doubleSpinBoxLeftToShoulder_valueChanged(double arg1)
{
    updateRobotQInitGoal(27,arg1,false);
}


void calc()
{
    p3d_vector3 r,p,q;
    double alpha;
    double c;
    double x,y,z;


    x = r[0];
    y = r[1];
    z = r[2];

    p[0] = - (y+z);
    p[1] =   (x+z);
    p[2] =   (x-y);

    p3d_vectNormalize(p,p);

    q[0] = x*y - y*y - x*z + z*z;
    q[1] = x*y - x*x - y*z - z*z;
    q[2] = x*x + x*z + y*y + y*z;

    p3d_vectNormalize(q,q);


    p3d_vector3 rand;

    if( (r[1]*rand[0]-r[0]*rand[1]) >= c  )  //A droite du plan HD z
    {
        if( (pow(p[0]*rand[0] + p[1]*rand[1] + p[2]*rand[2],2) + pow(q[0]*rand[0] + q[1]*rand[1] + q[2]*rand[2],2)) <= tan(alpha) * pow(r[0]*rand[0] + r[1]*rand[1] + r[2]*rand[2],2) )
        {   //Dans le cône
            double *cote;
            p3d_get_BB_rob_max_size(p3d_get_robot_by_name_containing("HERACLES"),cote);

            double rhum = sqrt(3) * (*cote) / 2;

            p3d_get_BB_rob_max_size(p3d_get_robot_by_name_containing("HACHET"),cote);

            double robj = sqrt(3) * (*cote) / 2;

            p3d_vector3 hg,gd;

            double dhg = p3d_vectNorm(hg);
            double dgd = p3d_vectNorm(gd);

            if( dhg >= rhum/2 && dhg <= rhum)
            { // A bonne distance de l'humain
                if( dgd >= robj && dgd <= 2*robj)
                {   // A bonne distance de l'objet
                    cout<<"ok";
                }
            }


        }
    }





}
